netapp_ontap.resources.svm_migration API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.svm_migration`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

# Overview

You can use this API to migrate an SVM from a source cluster to a destination cluster. During the migration, you can pause, resume, or abort the operation, and retrieve the migration status and transfer status of volumes in the SVM. The migrations APIs are only accessible from the destination cluster.

## Precondition

The cluster peering relationship should be created between the source and destination clusters prior to using this API.

## SVM migration APIs

The following APIs are used to manage SVM migration: - POST /api/svm/migrations - PATCH /api/svm/migrations/{uuid} - GET /api/svm/migrations/ - GET /api/svm/migrations/{uuid} - GET /api/svm/migrations/{svm_migration.uuid}/volumes - GET /api/svm/migrations/{svm_migration.uuid}/volumes/{volume.uuid} - DELETE /api/svm/migrations/{uuid}

## Important notes

The migration of temperature-sensitive storage efficiency (TSSE) volumes from AFF to FAS systems has a known limitation. The migration preserves the TSSE savings and after migration completes, the volume will not receive any further TSSE savings for the new data written on the volume.

## Starting a migration

To start a migration operation, issue a POST request to /svm/migrations. Parameters are provided in the body of the POST request to specify the source cluster and the source SVM.

## Monitoring the status of the SVM migration

You can use GET /svm/migrations to retrieve the status of the SVM migration and GET /svm/migrations/{svm_migration.uuid}/volumes to retrieve the transfer status of the volumes in the SVM migration.

### Possible errors before starting the migration

Configurations in the POST /svm/migrations request are validated before the SVM migration starts. If an invalid configuration is found or the migration pre-checks fail, an HTTP error code in the 4xx range is returned. No SVM migration operation is started.

### Polling the migration operation

After a successful POST /svm/migrations request is issued, an HTTP error code of 202 is returned along with a migration UUID and link in the body of the response. The SVM migration continues asynchronously and is monitored using the migration UUID and the GET /svm/migrations/{uuid} API.

### Errors during the migration operation

If a failure occurs during the SVM migration, the GET /svm/migrations response provides details of the error along with any error code fields.

### Pausing the migration operation

You can use PATCH /svm/migrations/{uuid} with the action "pause" to pause the SVM migration to update the SVM configuration on the source SVM.

### Resuming the migration operation

You can use PATCH /svm/migrations{uuid} with the action "resume" to resume the SVM migration from a paused state. You can modify the throttle value when you resume the SVM migration. To set the throttle value to unlimited, specify the throttle value as 0.

### Aborting the migration operation

You can use DELETE /svm/migrations/{uuid} to delete the SVM on the destination cluster if the SVM migration has failed or is paused. Use the DELETE /svm/migrations/{uuid} request to remove the SVM on the source cluster; this might be used when communication between the source and destination cluster is reduced.

## Retrieving the migration status

You can use GET /svm/migrations/{uuid} to retrieve the current status of your migration.

## Retrieving the volume transfer status

You can use GET /svm/migrations/{svm_migration.uuid}/volumes to retrieve the current transfer status of all volumes in the migrating SVM.

## Retrieving the volume transfer status of a specific volume

You can use GET /svm/migrations/{svm_migrations.uuid}/volumes/{volume.uuid} to retrieve the transfer status of a specific volume in the migrating SVM.

## Examples

### Starting a Migration

    # API
    /api/svm/migrations

### POST body included from file

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SvmMigration

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SvmMigration()
        resource.source = {"svm": {"name": "vs1"}, "cluster": {"name": "siteB"}}
        resource.post(hydrate=True)
        print(resource)

### Inline POST body

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SvmMigration

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SvmMigration()
        resource.source = {"svm": {"name": "vs1"}, "cluster": {"name": "siteB"}}
        resource.post(hydrate=True)
        print(resource)

### POST Response

    Date: Wed, 25 Aug 2021 19:04:47 GMT
    Server: libzapid-httpd
    X-Content-Type-Options: nosniff
    Cache-Control: no-cache,no-store,must-revalidate
    Location: /api/svm/migrations/517c5e74-05d7-11ec-a40f-005056bba9a5
    Content-Length: 189
    Content-Type: application/hal+json
    Keep-Alive: timeout=5, max=100
    Connection: Keep-Alive
    {
      "job": {
        "uuid": "5184a3e1-05d7-11ec-a40f-005056bba9a5",
        "_links": {
          "self": {
            "href": "/api/cluster/jobs/5184a3e1-05d7-11ec-a40f-005056bba9a5"
          }
        }
      }
    }

### Retrieving POST Job status

Use the link provided in the response to the POST request to fetch the status of the start operation

#### Request

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Job

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Job(uuid="5184a3e1-05d7-11ec-a40f-005056bba9a5")
        resource.get()
        print(resource)

#### Response

    Date: Wed, 25 Aug 2021 19:05:04 GMT
    Server: libzapid-httpd
    X-Content-Type-Options: nosniff
    Cache-Control: no-cache,no-store,must-revalidate
    Content-Type: application/hal+json
    Vary: Accept-Encoding
    Content-Encoding: gzip
    Content-Length: 224
    Keep-Alive: timeout=5, max=100
    Connection: Keep-Alive
    {
      "uuid": "5184a3e1-05d7-11ec-a40f-005056bba9a5",
      "description": "POST /api/svm/migrations/517c5e74-05d7-11ec-a40f-005056bba9a5",
      "state": "success",
      "message": "success",
      "code": 0,
      "start_time": "2021-08-25T15:04:48-04:00",
      "end_time": "2021-08-25T15:04:57-04:00",
      "_links": {
        "self": {
          "href": "/api/cluster/jobs/5184a3e1-05d7-11ec-a40f-005056bba9a5"
        }
      }
    }

### Retrieving all migrations

The location header in the POST operation provides the uuid of the migrate operation that was started using POST. Also, you can list all the migrate operations using the collection GET.

#### Request

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SvmMigration

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(SvmMigration.get_collection()))

#### Response

    Date: Wed, 25 Aug 2021 19:05:11 GMT
    Server: libzapid-httpd
    X-Content-Type-Options: nosniff
    Cache-Control: no-cache,no-store,must-revalidate
    Content-Type: application/hal+json
    Vary: Accept-Encoding
    Content-Encoding: gzip
    Content-Length: 170
    Keep-Alive: timeout=5, max=100
    Connection: Keep-Alive
    {
      "records": [
        {
          "uuid": "517c5e74-05d7-11ec-a40f-005056bba9a5",
          "_links": {
            "self": {
              "href": "/api/svm/migrations/517c5e74-05d7-11ec-a40f-005056bba9a5"
            }
          }
        }
      ],
      "num_records": 1,
      "_links": {
        "self": {
          "href": "/api/svm/migrations/"
        }
      }
    }

### Retrieving a specific migration

#### Request

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SvmMigration

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SvmMigration(uuid="517c5e74-05d7-11ec-a40f-005056bba9a5")
        resource.get()
        print(resource)

#### Response

    Date: Wed, 25 Aug 2021 19:05:33 GMT
    Server: libzapid-httpd
    X-Content-Type-Options: nosniff
    Cache-Control: no-cache,no-store,must-revalidate
    Content-Type: application/hal+json
    Vary: Accept-Encoding
    Content-Encoding: gzip
    Content-Length: 379
    Keep-Alive: timeout=5, max=100
    Connection: Keep-Alive
    {
      "uuid": "517c5e74-05d7-11ec-a40f-005056bba9a5",
      "state": "setup_configuration",
      "start_time": "2021-08-25T15:04:49-04:00",
      "current_operation": "start",
      "source": {
        "svm": {
          "uuid": "424b6002-fb1a-11eb-9383-005056bbcf32",
          "name": "vs1",
          "_links": {
            "self": {
              "href": "/api/svm/svms/424b6002-fb1a-11eb-9383-005056bbcf32"
            }
          }
        },
        "cluster": {
          "uuid": "b54babec-fb14-11eb-9383-005056bbcf32",
          "name": "siteB",
          "_links": {
            "self": {
              "href": "/api/cluster/peers/b54babec-fb14-11eb-9383-005056bbcf32"
            }
          }
        }
      },
      "destination": {
        "ipspace": {
          "uuid": "f305cf0b-fb14-11eb-829d-005056bba9a5",
          "name": "Default"
        }
      },
      "auto_cutover": false,
      "auto_source_cleanup": false,
      "throttle": 0,
      "_links": {
        "self": {
          "href": "/api/svm/migrations/517c5e74-05d7-11ec-a40f-005056bba9a5"
        }
      }
    }

### Pausing a migration

To pause the migration use the PATCH request on the migration UUID.

#### Request

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SvmMigration

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SvmMigration(uuid="517c5e74-05d7-11ec-a40f-005056bba9a5")
        resource.patch(hydrate=True, action="pause")

#### Response

    Date: Wed, 25 Aug 2021 19:06:11 GMT
    Server: libzapid-httpd
    X-Content-Type-Options: nosniff
    Cache-Control: no-cache,no-store,must-revalidate
    Content-Length: 189
    Content-Type: application/hal+json
    Keep-Alive: timeout=5, max=100
    Connection: Keep-Alive
    {
      "job": {
        "uuid": "82dea7c7-05d7-11ec-a40f-005056bba9a5",
        "_links": {
          "self": {
            "href": "/api/cluster/jobs/82dea7c7-05d7-11ec-a40f-005056bba9a5"
          }
        }
      }
    }

### Monitoring PATCH job status

Use the link provided in the response of the PATCH request to fetch the information of the patch job.

#### Request

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Job

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Job(uuid="82dea7c7-05d7-11ec-a40f-005056bba9a5")
        resource.get()
        print(resource)

#### Response

    Date: Wed, 25 Aug 2021 21:40:06 GMT
    Server: libzapid-httpd
    X-Content-Type-Options: nosniff
    Cache-Control: no-cache,no-store,must-revalidate
    Content-Type: application/hal+json
    Vary: Accept-Encoding
    Content-Encoding: gzip
    Content-Length: 222
    Keep-Alive: timeout=5, max=100
    Connection: Keep-Alive
    {
      "uuid": "82dea7c7-05d7-11ec-a40f-005056bba9a5",
      "description": "PATCH /api/svm/migrations/517c5e74-05d7-11ec-a40f-005056bba9a5",
      "state": "success",
      "message": "success",
      "code": 0,
      "start_time": "2021-08-25T15:06:11-04:00",
      "end_time": "2021-08-25T15:06:11-04:00",
      "_links": {
        "self": {
          "href": "/api/cluster/jobs/82dea7c7-05d7-11ec-a40f-005056bba9a5"
        }
      }
    }

### Aborting a migration

To abort the migration use the DELETE request on the migration UUID.

#### Request

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SvmMigration

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SvmMigration(uuid="517c5e74-05d7-11ec-a40f-005056bba9a5")
        resource.delete()

#### Response

    Date: Wed, 25 Aug 2021 22:57:23 GMT
    Server: libzapid-httpd
    X-Content-Type-Options: nosniff
    Cache-Control: no-cache,no-store,must-revalidate
    Content-Length: 189
    Content-Type: application/hal+json
    Keep-Alive: timeout=5, max=100
    Connection: Keep-Alive
    {
      "job": {
        "uuid": "cf870f19-05f7-11ec-a40f-005056bba9a5",
        "_links": {
          "self": {
            "href": "/api/cluster/jobs/cf870f19-05f7-11ec-a40f-005056bba9a5"
          }
        }
      }
    }

### Monitoring DELETE job status

Use the link provided in the response of the PATCH request to fetch the information of the patch job.

#### Request

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Job

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Job(uuid="cf870f19-05f7-11ec-a40f-005056bba9a5")
        resource.get()
        print(resource)

#### Response

    Date: Wed, 25 Aug 2021 23:05:47 GMT
    Server: libzapid-httpd
    X-Content-Type-Options: nosniff
    Cache-Control: no-cache,no-store,must-revalidate
    Content-Type: application/hal+json
    Vary: Accept-Encoding
    Content-Encoding: gzip
    Content-Length: 228
    Keep-Alive: timeout=5, max=100
    Connection: Keep-Alive
    {
      "uuid": "cf870f19-05f7-11ec-a40f-005056bba9a5",
      "description": "DELETE /api/svm/migrations/517c5e74-05d7-11ec-a40f-005056bba9a5",
      "state": "success",
      "message": "success",
      "code": 0,
      "start_time": "2021-08-25T18:57:23-04:00",
      "end_time": "2021-08-25T18:57:24-04:00",
      "_links": {
        "self": {
          "href": "/api/cluster/jobs/cf870f19-05f7-11ec-a40f-005056bba9a5"
        }
      }
    }

## Classes

`class SvmMigration (*args, **kwargs)`

  Provides information on SVM migration, default and user specified configurations, the state of the migration, and volume transfer metrics.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all SvmMigration resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('SvmMigration')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes the SVM migration.

    ### Related ONTAP commands

    - `vserver migrate abort`

    ### Learn more

    - `DOC /svm/migrations`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent SvmMigration resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the SVM migration status.

    ### Related ONTAP commands

    - `vserver migrate show`

    ### Learn more

    - `DOC /svm/migrations`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves the SVM migration status.

    ### Related ONTAP commands

    - `vserver migrate show`

    ### Learn more

    - `DOC /svm/migrations`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('SvmMigration')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Actions that can be performed during an SVM migration.

    ### Related ONTAP commands

    - `vserver migrate pause`
    - `vserver migrate resume`
    - `vserver migrate cutover`
    - `vserver migrate source-cleanup`

    ### Learn more

    - `DOC /svm/migrations`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('SvmMigration')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[SvmMigration], NetAppResponse]`

    Creates an SVM migration operation. This API must be executed on the destination cluster. This API creates an SVM on the destination cluster and preserves the SVM's identity specified in the source cluster. Optionally, you can specify the aggregate list for creating the volumes, and IPspace. You can perform pre-checks to verify if SVM migration is possible, by setting the "check-only" option to "true". By default the values for auto-source-cleanup and auto-cutover is true.

    ### Required properties

    - `source.svm.name` or `source.svm.uuid` - Source SVM name or source SVM UUID.
    - `source.cluster.name` or `source.cluster.uuid` - Source cluster name or source cluster UUID

    ### Optional properties

    - `destination.ipspace.name` or `destination.ipspace.uuid` - Destination IP Space name or UUID where the SVM will be migrated to.
    - `destination.volume_placement.aggregates` - List of aggregates where the migrating volumes should go on the destination.
    - `destination.volume_placement.volume_aggregate_pairs` - List of volume aggregate pairs indicating where the migrating volumes should go on the destination.
    - `ip_interface_placement` - List of source SVM's IP interface and port pairs on the destination for migrating the SVM's IP interfaces.
    - `auto_cutover` - Option to specify whether to perform cutover automatically. Default is true.
    - `auto_source_cleanup` - Option to specify whether to perform source cleanup automatically. Default is true.
    - `check_only` - Option to perform all the prechecks for migrate without actually starting the migrate. Default is false.
    - `throttle` - Option to specify a throttle value in KB/s. Defaults to unlimited.

    ### Related ONTAP commands

    - `vserver migrate start`

    ### Learn more

    - `DOC /svm/migrations`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes the SVM migration.

    ### Related ONTAP commands

    - `vserver migrate abort`

    ### Learn more

    - `DOC /svm/migrations`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the migration status of an individual SVM.

    ### Important notes

    - The "migrations" object includes a large set of fields and can be expensive to retrieve.
    - REST APIs only expose a data SVM as an SVM.
    - There are subsystem specific errors that can be returned from this endpoint. If a subsystem specific error is returned and this is the first migrate operation attempt, it is embedded in one of the following errors. If a subsystem specific error is returned and this is not the first migrate operation attempt, the subsystem specific error is returned directly.

    ### Example

        Retrieving an individual SVM migration status.
        <br/>
        ```
        GET "/api/svm/migrations/a14ae39f-8d85-11e9-b4a7-00505682dc8b/svms/f16f0935-5281-11e8-b94d-005056b46485"
        ```
        <br/>

    ### Learn more

    - `DOC /svm/migrations`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Actions that can be performed during an SVM migration.

    ### Related ONTAP commands

    - `vserver migrate pause`
    - `vserver migrate resume`
    - `vserver migrate cutover`
    - `vserver migrate source-cleanup`

    ### Learn more

    - `DOC /svm/migrations`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates an SVM migration operation. This API must be executed on the destination cluster. This API creates an SVM on the destination cluster and preserves the SVM's identity specified in the source cluster. Optionally, you can specify the aggregate list for creating the volumes, and IPspace. You can perform pre-checks to verify if SVM migration is possible, by setting the "check-only" option to "true". By default the values for auto-source-cleanup and auto-cutover is true.

    ### Required properties

    - `source.svm.name` or `source.svm.uuid` - Source SVM name or source SVM UUID.
    - `source.cluster.name` or `source.cluster.uuid` - Source cluster name or source cluster UUID

    ### Optional properties

    - `destination.ipspace.name` or `destination.ipspace.uuid` - Destination IP Space name or UUID where the SVM will be migrated to.
    - `destination.volume_placement.aggregates` - List of aggregates where the migrating volumes should go on the destination.
    - `destination.volume_placement.volume_aggregate_pairs` - List of volume aggregate pairs indicating where the migrating volumes should go on the destination.
    - `ip_interface_placement` - List of source SVM's IP interface and port pairs on the destination for migrating the SVM's IP interfaces.
    - `auto_cutover` - Option to specify whether to perform cutover automatically. Default is true.
    - `auto_source_cleanup` - Option to specify whether to perform source cleanup automatically. Default is true.
    - `check_only` - Option to perform all the prechecks for migrate without actually starting the migrate. Default is false.
    - `throttle` - Option to specify a throttle value in KB/s. Defaults to unlimited.

    ### Related ONTAP commands

    - `vserver migrate start`

    ### Learn more

    - `DOC /svm/migrations`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class SvmMigrationSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SvmMigration object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `auto_cutover: bool GET POST`

    Optional property that when set to true automatically performs cutover when the migration state reaches "ready for cutover".

  `auto_source_cleanup: bool GET POST`

    Optional property that when set to true automatically cleans up the SVM on the source cluster after the migration cutover.

  `check_only: bool POST`

    Optional property that when set to true performs only migration pre-checks not the actual migration.

  `current_operation: str GET`

    The current_operation field of the svm_migration.

  `destination: SvmMigrationDestination GET POST PATCH`

    Destination cluster details for the SVM migration.

  `ip_interface_placement: SvmMigrationIpInterfacePlacement GET POST PATCH`

    Optional property used to specify the IP interface placement in the destination. It is input only and is not returned by a subsequent GET.

  `last_failed_state: str GET`

    The last_failed_state field of the svm_migration.

  `last_operation: str GET`

    The last_operation field of the svm_migration.

    Valid choices:

    - none
    - start
    - resume
    - pause
    - cleanup
    - cutover
  `messages: List[EmsUiMessageArguments] GET`

    Errors and warnings returned/displayed during migration.

  `point_of_no_return: bool GET`

    Indicates if the migration has progressed beyond the point of no return. When true, the migration cannot be aborted or paused. When false, the migration can be paused or aborted.

  `post_ponr_retry_count: Size GET`

    Number of times the migration restarted after the point of no return.

  `restart_count: Size GET`

    Number of times migrate restarted the transfer, for example, rollback to transfer after starting the cutover.

  `source: SvmMigrationSource GET POST PATCH`

    Source cluster details for the SVM migration.

  `state: str GET`

    The state field of the svm_migration.

  `throttle: Size GET POST PATCH`

    Optional property to specify a throttle value in KB/s for each individual volume transfer. Defaults to 0 if not set, which is interpreted as unlimited. The minimum throttle value is 4 KB/s, so if you specify a throttle value between 1 and 4, it will be treated as if you specified 4.

  `time_metrics: SvmMigrationTimeMetrics GET`

    Various time metrics details

  `uuid: str GET`

    SVM migration UUID

    Example: 4ea7a442-86d1-11e0-ae1c-123478563412